#
# spec file for package splashy
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           splashy
Summary:        A complete user-space boot splash system
License:        GPL-2.0+
Group:          System/Boot
Version:        0.3.13
Release:        53.2
Url:            http://alioth.debian.org/projects/splashy/
Requires(pre):  coreutils
Source:         http://alioth.debian.org/frs/download.php/file/2691/%{name}-%{version}.tar.gz
Source1:        setup-splashy.sh
Source2:        pm-utils-splashy.sh
Source3:        themes.tar.bz2
Source4:        README.themes
Source5:        splashy-branding-openSUSE.tar.bz2
Source6:        splashy-branding-SLED.tar.bz2
# Werror breaks build when used with fortify (we could also empty the _fortify_cflags macro)
#Patch0:         splashy.diff
Patch1:         splashy-0.3.8-fix-compiler-warnings.patch
Patch2:         splashy-0.3.8-glib.patch
Patch3:         splashy-disable-x11input.patch
Patch4:         splashy-0.3.13-fix-theme-path.patch
Patch5:         fix_autogen_version.diff
Patch6:         gcc46-build-fixes.patch
Patch7:         splashy-exits-prematurely-fix.patch
Patch8:         update-initramfs.patch
Patch9:         splashy-glib231.patch
Patch10:        automake-1.12.patch
Patch11:        splashy-missing-current-theme-in-font-path.patch
Patch12:        splashy-fix-error-no-create-window-support.patch
BuildRequires:  DirectFB-devel
BuildRequires:  ImageMagick-devel
BuildRequires:  file-devel
BuildRequires:  glib2-devel
#BuildRequires:	procps-devel
BuildRequires:  freetype2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
# For directfb-config
Requires:       DirectFB
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Splashy is a next generation boot splashing system for Linux systems.
Unlike other splashing systems, it needs no patches to the kernel and
it´s installed like a normal package. Make your boot process eye-candy
with Splashy!

Some of Splashy´s most noticeable features include:

* Require zero kernel patches/full functionality in user-space

* Boot/halt/reboot/runlevel-switch support

* Progressbar support (with optional border)

* Verbose mode (with F2/ESC keys)

* Configuration file in XML

* Cope with any video-mode resolution/size

* Cope with 8, 16, and 24 bit framebuffers

* Alpha channel (transparency) support

* Video mode detection

* Initramfs support

* TrueType2 fonts support

* Lots of image/animation file formats supported: jpg, png, gif,
   mpg, swf

* Low dependencies and code in C to best perform

* Full LSB support

* Multiple themes support

* Really easy to create new themes

* X detection on exit

* Smooth progressbar movement

* Animations support

* Fade in/out effects

* Totally configurable

%package devel
Summary:        Development tools for programs using libsplashy
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains the header files and libraries needed for
developing programs using libsplashy.

%package themes
Summary:        Additional themes for splashy
Group:          System/Boot
Requires:       %{name} = %{version}-%{release}

%description themes
Available themes: - fingerprint

- aqua

- mepis baghira

- default splashy theme



%package	branding-openSUSE
Summary:        Splashy branding for openSUSE
Group:          System/Boot
Supplements:    packageand(splashy:branding-openSUSE)
Provides:       %{name}-branding = %{version}
Conflicts:      otherproviders(%{name}-branding)
Requires(pre):  %{name} >= 0.3.8

%description	branding-openSUSE
Splashy branding for openSUSE Linux distribution

%package	branding-SLED
Summary:        Splashy branding for SLED
Group:          System/Boot
Supplements:    packageand(splashy:branding-SLED)
Provides:       %{name}-branding = %{version}
Conflicts:      otherproviders(%{name}-branding)
Requires(pre):  %{name} >= 0.3.8

%description	branding-SLED
Splashy branding for SUSE Linux Enterprise Desktop

%post branding-openSUSE
if [ -x '%{_sbindir}/%{name}_config' ] ; then
'%{_sbindir}/%{name}_config' --set-theme openSUSE
fi

%postun branding-openSUSE
if [ -x '%{_sbindir}/%{name}_config' ] ; then
%{_sbindir}/%{name}_config --set-theme default
fi

%post branding-SLED
if [ -x '%{_sbindir}/%{name}_config' ] ; then
'%{_sbindir}/%{name}_config' --set-theme SLED
fi

%postun branding-SLED
if [ -x '%{_sbindir}/%{name}_config' ] ; then
'%{_sbindir}/%{name}_config' --set-theme default
fi

%package        mkinitrd
Summary:        Setup script for mkinitrd
Group:          System/Boot
Supplements:    packageand(%{name}:mkinitrd)
Provides:       %{name}:/lib/mkinitrd/scripts/setup-splashy.sh
Requires(post):  %{name} = %{version}
Requires(postun):%{name} = %{version}
Requires(post):  mkinitrd
Requires(postun):mkinitrd

%description    mkinitrd
Setup script for mkinitrd adds splashy support into initial ram disk.

%post mkinitrd
/sbin/mkinitrd_setup

%postun mkinitrd
/sbin/mkinitrd_setup

%prep
%setup -q
%setup -T -D -a 5
%setup -T -D -a 6
%patch1
%patch2
%patch3
%patch4 -p1
%patch5
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
find . -type f | xargs perl -pi -e "s|/usr/lib/|%{_libdir}/|g"
find . -type f | xargs perl -pi -e "s|/lib/|/%{_lib}/|g"
# build gets confused on x86_64 because of this .la file
rm -f src/libglib-2.0.la
# automake-1.13 deprecated this macro
sed -i 's/AM_CONFIG_HEADER/AC_CONFIG_HEADERS/' configure.ac

%build
NOCONFIGURE=1 ./autogen.sh
%configure --prefix=/ --disable-static CFLAGS="$RPM_OPT_FLAGS -fgnu89-inline"
make 

%pre
if test -d %{_sysconfdir}/splashy/themes -a ! -L %{_sysconfdir}/splashy/themes; then
  mv %{_sysconfdir}/splashy/themes %{_sysconfdir}/splashy/themes.bak
fi

%install
export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL="1"
%makeinstall
cp '-t%{buildroot}%{_datadir}/%{name}' -r themes 
rm '%{buildroot}'/usr/lib*/lib%{name}*.la
# remove Debian-specific files
#remove splashy init script for now, it's not working anyway
#TODO, fixup init-script, install with chmod +x, link to /usr/sbin/rcsplash
rm -rf  \
	'%{buildroot}%{_sysconfdir}/lsb-base-logging.sh' \
    '%{buildroot}%{_sysconfdir}/console-tools' \
    '%{buildroot}%{_datadir}/initramfs-tools' \
    '%{buildroot}%{_sysconfdir}/init.d/%{name}'
mkdir -p '%{buildroot}/lib/mkinitrd/scripts'
install -m 755 '%{SOURCE1}' '%{buildroot}/lib/mkinitrd/scripts/'
tar xvf '%{SOURCE3}' -C '%{buildroot}%{_datadir}/%{name}/'
install -m 644 '-t%{buildroot}%{_datadir}/%{name}/themes' '%{SOURCE4}'
ln -s '-t%{buildroot}%{_sysconfdir}/%{name}/' '%{_datadir}/%{name}/themes/README.themes'
%if 0 
mkdir -p $RPM_BUILD_ROOT/usr/lib/pm-utils/sleep.d/
cp %{SOURCE2} $RPM_BUILD_ROOT/usr/lib/pm-utils/sleep.d/99splashy
%{nil remove translations for now TODO: %find_lang %name}
%endif
rm '%{buildroot}/%{_datadir}/locale/'*'/LC_MESSAGES/%{name}.mo'

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README TODO 
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/default/*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/config.xml
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%dir %{_datadir}/%{name}
%{_libdir}/lib%{name}*.so.*
%{_datadir}/splashy/schemas
# this is a symbolic link to /usr/share/splashy/themes
%{_sysconfdir}/%{name}/README.themes
%{_sysconfdir}/%{name}/themes
%dir %{_datadir}/%{name}/themes
%{_datadir}/%{name}/themes/default
%doc %{_datadir}/%{name}/themes/README.themes

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}*.h
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}.pc

%files themes
%defattr(-,root,root)
%dir %{_datadir}/%{name}/themes
%{_datadir}/%{name}/themes/fingerprint
%{_datadir}/%{name}/themes/mepis_baghira
%{_datadir}/%{name}/themes/aqua
%{_datadir}/%{name}/themes/openSUSE-zz

%files branding-openSUSE
%defattr(-,root,root)
%dir %{_datadir}/%{name}/themes
%{_datadir}/%{name}/themes/openSUSE

%files branding-SLED
%defattr(-,root,root)
%dir %{_datadir}/%{name}/themes
%{_datadir}/%{name}/themes/SLED

%files mkinitrd
%defattr(-,root,root)
%dir /lib/mkinitrd
%dir /lib/mkinitrd/scripts
/lib/mkinitrd/scripts/setup-%{name}.sh

%changelog
* Sun Jun 21 2015 antoine.belvire@laposte.net
- Fix compilation with GCC5: add -fgnu89-inline to CFLAGS.
* Wed Sep 24 2014 sfalken@opensuse.org
- Added %%dir declarations for /lib/mkinitrd entries
* Fri Jun 28 2013 mchang@suse.com
- add splashy-missing-current-theme-in-font-path.patch (bnc#779048)
- add splashy-fix-error-no-create-window-support.patch (bnc#779048)
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Mar  5 2013 seife+obs@b1-systems.com
- fix build with new automake 1.13, simplify automake-1.12.patch
* Thu Dec 27 2012 giecrilj@stegny.2a.pl
- move README.themes to %%{_datadir}
- macroize the spec file
- minor syntactic tweaks
* Mon Jul 30 2012 mvyskocil@suse.cz
- split mkinitrd setup script to separate package allows users to
  skip it from initrd without breaking suspend package
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Sun Apr 22 2012 dimstar@opensuse.org
- Add splashy-glib231.patch: Fix build with glib 2.31.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Nov  6 2011 aj@suse.de
- For openSUSE it's mkinitrd and not update_initramfs (bnc#542595).
  Patch: update-initramfs.patch
* Tue Jul 26 2011 mmarek@suse.cz
- setup-splashy.sh: Drop the hardcoded list of libraries, let
  mkinitrd figure it out itself (bnc#649150).
* Wed Jul 13 2011 aj@suse.de
- libglib moved to /usr, adjust update-splashy.sh.
- Fix branding spec file rules.
- Replace deprecated run_ldconfig macro with direct call.
* Tue May  3 2011 ro@suse.de
- update description
* Tue May  3 2011 jslaby@suse.de
- fix gcc 4.6 build
- splashy exits prematurely fix
* Tue Jan 25 2011 hmacht@suse.de
- Revert previous fix, always use the symbolic link
  /usr/lib/libglib-2.0.so.0 (bnc#664793)
* Wed Oct 27 2010 aj@suse.de
- Fix path for libglib.
* Mon Oct 25 2010 aj@suse.de
- Update for new libfusion and glib versions.
* Mon Sep 27 2010 hmacht@suse.de
- update libpng to libpng14 in setup-splashy.sh (bnc#634667)
* Fri Jun 18 2010 badshah400@gmail.com
- Updated splashy-branding-openSUSE.tar.bz2 with artwork for 11.3
* Mon Apr 19 2010 aj@suse.de
- Require DirectFB for directfb-config (bnc#597667).
* Wed Feb 24 2010 aj@suse.de
- Update for new libfusion major version.
* Tue Oct 13 2009 hmacht@suse.de
- update openSUSE branding (bnc#533989)
* Fri Jul 17 2009 tittiatcoke@gmail.com
- add fix_autogen_version.diff to enable autogen to find automake 1.11
* Wed Apr 15 2009 hmacht@suse.de
- add splashy-0.3.13-fix-theme-path.patch to fix
  /etc/splashy/config.xml
- update to 0.3.13:
  * adds default theme to initramfs so we can fall back in case of
    problems with a newer theme
  * fixes font problem with libdirectfb
  * fixes LSB script issue that prevented some applications to install
    correctly if Splashy was removed/missing (mysql server, etc...)
  * no major C changes, minor bug fixes
  * closes a number of bugs from bugs.debian.org/splashy which apply to
    other distros also
  * fixes problems with uswsusp
  * fixes problems with kdm
  * no major C changes, mostly scripts
  * implements chroot() as a command passed from splashy_update
  * works better with resume-from-RAM/Disk when uswsusp is used from
    initramfs
  * suggests to run update-initramfs -u when a theme is changed with
    splashy_config
  * removes boot dependency argument $all from initrc script (for LSB)
  * turns off cursor in TTY consoles to avoid showing artifacts when X
    starts
  * other bug fixes
  * plenty of bug fixes (Thanks Niko Araya for helping us sort them out)
    (See ChangeLog)
  * Splashy works better with encrypted hard disk (LUKS) and
    getstring/getpass prompts early at boot
  * lots of bug/thinko fixes from John Hughes, for which we are very glad!
  * fixes issues with progress bar during shutdown (Thanks to Matthijs
    Kooijman)
  * lsb-base-logging.sh LSB functions are a bit more complete
  * clears TTYs properly whenever Splashy is about to exit
  * detects display managers better (gdm, kdm, xdm)
  * hu translation added (Thanks Miklos Vajna)
  * br translation added (Thanks Amadeu Andrade Barbosa Júnior)
  * added more checks at initramfs to ensure Splashy can be started
    (Thanks Luca Capello)
* Fri Dec 19 2008 seife@suse.de
- fix splash screen during resume (link /etc/splashy/themes added)
* Sat Nov 29 2008 ro@suse.de
- check if binary really exists in postinstall scripts
  (needed with possibly cyclic deps)
* Wed Nov  5 2008 hmacht@suse.de
- split off splashy-branding-* packages (bnc#440898)
* Tue Sep 30 2008 hmacht@suse.de
- disable DirectFB-x11input module, it triggers a segfault in
  DirectFB (bnc#430235)
* Mon Sep 29 2008 hmacht@suse.de
- adjust library paths in setup-splashy.sh due to DirectFB update
  (bnc#430130)
* Wed May 21 2008 hmacht@suse.de
- package old openSUSE theme as openSUSE-zz in splashy-themes package
- add new openSUSE theme to core package and adjust
  splashy-default-theme.patch accordingly (bnc#387647)
* Fri Feb  1 2008 hmacht@suse.de
- adjust paths and libraries in setup-splashy.sh (mkinitrd)
* Tue Jan 29 2008 hmacht@suse.de
- (bnc#354982)
  - remove link /etc/splashy/themes and add README.themes instead
  - patch splashy configuration to look at /usr/share/splashy/themes for
  themes instead
  - package openSUSE theme in splashy.rpm and upstream default theme in
  splashy-themes.rpm
* Mon Jan 28 2008 hmacht@suse.de
- /etc/splashy/themes was a directory and is now a link, so remove
  the directory on update (b.n.c. 354982)
* Tue Jan 15 2008 hmacht@suse.de
- update to 0.3.8:
  - remove splashy-static.patch
  - add patch splashy-0.3.8-glib.patch
  - Changes between 0.3.7 and 0.3.8
  * Bug fixes:
  - Changes between 0.3.6 and 0.3.7
  * all static build dropped in favor of shared libraries. If your
    distribution does not support initramfs shared binaries, or you are
    using Splashy from a thin-client server, you will need to re-enable
    static on your own. Please refer to configure.ac and src/Makefile.am
  * scrolls text during boot (splashy_update "scroll text to display")
  * splashy_update commands print_scroll is now just scroll. Same for
    its alias "TEXT_SCROLL->SCROLL)
  * splashy_update command clrprint is now just "clear"
  * adds verbose text when pressing F2 (again). This time is done using
    LSB scripts not reading the console files (/dev/vcs*)
  * LSB script writes splashy PID to /var/run/sendsigs.omit which is
    used by /etc/init.d/sendsigs to killall5 all processes at
    shutdown/reboot. This tells the system to ignore killing splashy during
    shutdown/reboot.
  * adds international support. Translators needed!
    http://splashy.alioth.debian.org/i18n/
  * uses the real size of the screen and not that reported by the
    surface (Thanks to DeX77 from #frugalware for helping to get this
    fixed)
  - Changes between 0.3.5 and 0.3.6
  * Documentation updates
  * Support for OpenSuSE/Fedora and other RPM-based systems
  * Splashy now works with Directfb 1.x
  * Splashy runs from initramfs under Init again (Thanks to RPath Linux
    and Directfb Dev Team) (upstart works just like before)
  * Themes are now in /usr/share/splashy/themes and a symlink from
    /etc/splashy/themes points to that location (See README for more)
* Wed Oct 17 2007 hmacht@suse.de
- use giant if-clause to never ever return from a mkinitrd script
  which would result in the initrd build process to fail
  (according to novell bug 331785, comment 8)
* Thu Oct 11 2007 hmacht@suse.de
  Update to upstream 0.3.5:
  - Make init scripts consistent. STEPS_DIR can be defined in
  /etc/default/splashy
  - bugfixes
  - documentation updates
* Tue Sep 11 2007 seife@suse.de
- fix wrong path in the theme check
- do not exit in mkinitrd script since this script is sourced
* Mon Sep 10 2007 seife@suse.de
- never abort mkinitrd because of potential splashy errors
* Sun Sep  9 2007 seife@suse.de
- fix setup-splashy.sh error if the configured theme is not there
* Wed Sep  5 2007 hmacht@suse.de
- add splashy-themes package, only openSUSE theme remains in the
  original package
- add themes Fingerprint, Mepis Bahira, Aqua and default splashy
  theme to splashy-themes package
* Mon Sep  3 2007 seife@suse.de
- do not put /etc/suspend.conf into the initrd
* Fri Aug 31 2007 seife@suse.de
- fix setup-splashy.sh in case the user changed his config.xml
* Mon Aug 27 2007 hmacht@suse.de
- setup-splashy.sh script did not copy dynamic libraries to initrd
  if static ones were not present in installed system
- add openSUSE theme by Jakub Steiner and use as default
* Mon Aug 20 2007 hmacht@suse.de
- do not install 99splashy pm-utils hook to create the screenshot
  before suspending. There are complications with the timeframe
  and with the desktop screensaver kicking in
* Mon Aug  6 2007 hmacht@suse.de
- call /sbin/mkinitrd_setup in %%postun to remove links
  (novell bug 297219)
- exit gracefully if convert is not installed
* Fri Aug  3 2007 hmacht@suse.de
- pm-utils-splashy.sh: Don't create screenshot if splash is
  disabled
* Wed Jul 25 2007 hmacht@suse.de
- add hook for pm-utils to create a screenshot of the desktop to
  show as suspend image
- add mkinitrd script to integrate splashy into the initrd
- splashy-default-theme.diff: slightly adjust the default theme
  configuration to fulfil our needs
* Fri Jun 29 2007 hmacht@suse.de
- initial submission
